/* ==================================================================
   File: NetworkSupport.h

   This file provides functions to send TCP/IP messages to the
   flight simulation and receive responses back.

   bool GetSocket()
       Attempts to get a socket from the OS.  Saves the socket handle
       in SessionSocket and returns true on success.

   bool MakeConnection()
       Attempts to make a TCP connection with the server.  Returns
       true on success and sets the global "Connected" to true.

   void CloseConnection()
       Closes the connection with the server.  Sets the global
       "Connected" to false.

   bool SendCommand(char *Buffer, int Count)
       Takes a character buffer and number of bytes in the buffer and
       sends the data to the simulation.  Returns true on success.

   bool ReceiveResponse(char *Buffer, int Count)
       Takes a pointer to a character buffer and the maximum number of
       characters to strore.  Waits for the simulation to send a message
       and fills the buffer with the data.  Returns true on success.

            Copyright (C) 2014 Richard C. Wagner
   This file is offered under the GNU General Public License.
   Please see the license statement at the end of the file.
   =============================================================== */


// ==================  Globals for use here.  =======================

int          SessionPort = 20248;
char         szServerName[20] = {"localhost"};
unsigned int SessionSocket;
struct       sockaddr_in SockAddr;
bool         Connected = false;

bool GetSocket()
{
    SessionSocket = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);
    if (SessionSocket == INVALID_SOCKET)
        return false;
    else
        return true;
}

bool MakeConnection()
{
    int  result;
    char szIPADDRESS[20];

    Connected = false;
    if (strcmp(szServerName, "localhost") == 0)
        strcpy(szIPADDRESS, "127.0.0.1");
    else
        strcpy(szIPADDRESS, szServerName);
    SockAddr.sin_family = AF_INET;
    SockAddr.sin_port = htons (SessionPort);
    SockAddr.sin_addr.S_un.S_addr = inet_addr (szIPADDRESS);
    result = connect(SessionSocket, (SOCKADDR *) &SockAddr, sizeof (SockAddr));
    if (result == 0)
        Connected = true;
    return Connected;
}

void CloseConnection()
{
    closesocket(SessionSocket);
    Connected = false;
    return;
}

bool SendCommand(char *Buffer, int Count)
{
    int result;

    result = send(SessionSocket, Buffer, Count, 0);
    if (result > 0)
        return true;
    else
        return false;
}

bool ReceiveResponse(char *Buffer, int Count)
{
    int result;

    result = recv(SessionSocket, Buffer, Count, 0);
    if (result > 0)
        return true;
    else
        return false;
}


/* ====================  License Statement  =========================
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
   =============================================================== */
